@@ -17,8 +17,8 @@ sub import {
         goto &perl5i::latest::import;
     }
     else {
-        require Carp;
-        Carp::croak(<<END);
+        require Carp::Fix::1_25;
+        Carp::Fix::1_25::croak(<<END);
 perl5i will break compatibility in the future, you can't just "use perl5i".
 
 Instead, "use $Latest" which will guarantee compatibility with all
@@ -247,7 +247,7 @@ functionality without polluting the global namespace.
 L<autobox::Core> wraps a lot of Perl's built in functions so they can
 be called as methods on unblessed variables.  C<< @a->pop >> for example.
 
-=head3 alias()
+=head3 alias
 
     $scalar_reference->alias( @identifiers );
     @alias->alias( @identifiers );
@@ -302,9 +302,11 @@ This is basically a nicer way to say:
 
 =head2 Scalar Autoboxing
 
-perl5i adds some methods to scalars of its own.
+All of the methods provided by L<autobox::Core> are available from perl5i.
 
-=head3 center()
+in addition, perl5i adds some methods of its own.
+
+=head3 center
 
     my $centered_string = $string->center($length);
     my $centered_string = $string->center($length, $character);
@@ -436,7 +438,7 @@ immediately call $module's C<import> method to emulate a C<use>.
     # like "use $module;" if that worked
     $module->require->import;
 
-=head3 wrap()
+=head3 wrap
 
     my $wrapped = $string->wrap( width => $cols, separator => $sep );
 
@@ -448,11 +450,11 @@ the newline character "\n".
 
 See L<Text::Wrap> for details.
 
-=head3 ltrim()
+=head3 ltrim
 
-=head3 rtrim()
+=head3 rtrim
 
-=head3 trim()
+=head3 trim
 
     my $trimmed = $string->trim;
     my $trimmed = $string->trim($character_set);
@@ -472,14 +474,14 @@ whitespace.
     my $string = '-> test <-'->trim('-><');  # ' test '   
 
 
-=head3 title_case()
+=head3 title_case
 
     my $name = 'joe smith'->title_case;   # Joe Smith
 
 Will uppercase every word character that follows a wordbreak character.
 
 
-=head3 path2module()
+=head3 path2module
 
     my $module = $path->path2module;
 
@@ -491,7 +493,7 @@ For example,
 It will throw an exception if given something which could not be a
 path to a Perl module.
 
-=head3 module2path()
+=head3 module2path
 
     my $path = $module->module2path;
 
@@ -501,6 +503,16 @@ For example,
     "Foo::Bar"->module2path;  # "Foo/Bar.pm"
 
 
+=head3 is_module_name
+
+    my $is_valid = $string->is_module_name;
+
+Will return true if the $string is a valid module name.
+
+    "Foo::Bar"->is_module_name;  # true
+    "Foo/Bar"->is_module_name;   # false
+
+
 =head3 group_digits
 
     my $number_grouped     = $number->group_digits;
@@ -509,7 +521,7 @@ For example,
 Turns a number like 1234567 into a string like 1,234,567 known as "digit grouping".
 
 It honors your current locale to determine the separator and grouping.
-This can be overriden using C<%options>.
+This can be overridden using C<%options>.
 
 NOTE: many systems do not have their numeric locales set properly
 
@@ -555,7 +567,7 @@ is useful when you want a predictable result regardless of the user's
 locale settings.
 
 C<%options> defaults to C<< ( separator => ",", grouping => 3, decimal_point => "." ) >>.
-Each key will be overriden individually.
+Each key will be overridden individually.
 
     1234->commify;                      # 1,234
     1234->commify({ separator => "." });  # 1.234
@@ -570,20 +582,22 @@ Reverses a $string.
 Unlike Perl's reverse(), this always reverses the string regardless of context.
 
 
-=head2 List Autoboxing
+=head2 Array Autoboxing
+
+The methods provided by L<autobox::Core/Array Methods> are available
+from perl5i.
 
 All the functions from L<List::Util> and select ones from
-L<List::MoreUtils> are all available as methods on unblessed arrays and array refs.
+L<List::MoreUtils> are all available as methods on unblessed arrays
+and array refs: first, max, maxstr, min, minstr, minmax, shuffle,
+reduce, sum, any, all, none, true, false, uniq and mesh.
 
-first, max, maxstr, min, minstr, minmax, shuffle, reduce, sum, any,
-all, none, true, false, uniq and mesh.
-
-The have all been altered to return array refs where applicable in
+They have all been altered to return array refs where applicable in
 order to allow chaining.
 
     @array->grep(sub{ $_->is_number })->sum->say;
 
-=head3 foreach()
+=head3 foreach
 
     @array->foreach( func($item) { ... } );
 
@@ -606,8 +620,46 @@ A normal subroutine with no signature will get one at a time.
 If @array is not a multiple of the iteration (for example, @array has
 5 elements and you ask 2 at a time) the behavior is currently undefined.
 
+=head3 as_hash
 
-=head3 diff()
+    my %hash = @array->as_hash;
+
+This method returns a %hash where each element of @array is a key.
+The values are all true.  Its functionality is similar to:
+
+    my %hash = map { $_ => 1 } @array;
+
+Example usage:
+
+    my @array = ("a", "b", "c");
+    my %hash = @array->as_hash;
+    say q[@array contains 'a'] if $hash{"a"};
+
+=head3 pick
+
+    my @rand = @array->pick($number);
+
+The pick() method returns a list of $number elements in @array.
+If $number is larger than the size of the list, it returns the entire list shuffled.
+
+Example usage:
+
+    my @array = (1, 2, 3, 4);
+    my @rand = @array->pick(2);
+
+=head3 pick_one
+
+    my $rand = @array->pick_one;
+
+The pick_one() method returns a random element in @array.  
+It is similar to @array->pick(1), except that it does not return a list.
+
+Example usage:
+
+    my @array = (1,2,3,4);
+    my $rand = @array->pick_one;
+
+=head3 diff
 
 Calculate the difference between two (or more) arrays:
 
@@ -646,7 +698,33 @@ L<Path::Class>, etc.), it tries its best to treat them as strings or numbers.
     [ $uri ]->diff( [ $uri2 ] );                 # empty, they are equal
 
 
-=head3 intersect()
+=head3 popn
+
+    my @newarray = @array->popn($n);
+
+L<Pops|perlfunc/pop> C<$n> values from the C<@array>.
+
+If C<$n> is greater than the length of C<@array>, it will return the
+whole C<@array>.  If C<$n> is 0, it will return an empty array.
+
+A negative C<$n> or non-integer is an error.
+
+    my @array = (1, 2, 3, 4, 5);
+    my @newarray = @array->popn(3); # (3, 4, 5)
+
+
+=head3 shiftn
+
+       my @newarray = @array->shiftn($n);
+
+Works like L<popn>, but it L<shifts|perlfunc/shift> off the front of
+the array instead of popping off the end.
+
+    my @array = (1, 2, 3, 4, 5);
+    my @newarray = @array->shiftn(3); # (1, 2, 3)
+
+
+=head3 intersect
 
     my @a = (1 .. 10);
     my @b = (5 .. 15);
@@ -660,11 +738,11 @@ As with C<diff()>, it works with any number of arrays, nested data
 structures of arbitrary depth, and handles overloaded objects
 graciously.
 
-=head3 ltrim()
+=head3 ltrim
 
-=head3 rtrim()
+=head3 rtrim
 
-=head3 trim()
+=head3 trim
 
     my @trimmed = @list->trim;
     my @trimmed = @list->trim($character_set);
@@ -684,7 +762,24 @@ which will determine what characters should be trimmed.
 
 =head2 Hash Autoboxing
 
-=head3 flip()
+All of the methods provided by L<autobox::Core/Hash Methods> are
+available from perl5i.
+
+In addition...
+
+=head3 each
+
+Iterate through each key/value pair in a hash using a callback.
+
+    my %things = ( foo => 23, bar => 42 );
+    %things->each( func($k, $v) {
+        say "Key: $k, Value: $v"
+    });
+
+Unlike the C<each> function, individual calls to each are guaranteed
+to iterate through the entirety of the hash.
+
+=head3 flip
 
 Exchanges values for keys in a hash.
 
@@ -704,7 +799,7 @@ nested hashes.
     { foo => [ 'bar', 'baz' ] }->flip; # dies
 
 
-=head3 merge()
+=head3 merge
 
 Recursively merge two or more hashes together using L<Hash::Merge::Simple>.
 
@@ -725,7 +820,7 @@ It also works with nested hashes, although it won't attempt to merge
 array references or objects. For more information, look at the
 L<Hash::Merge::Simple> docs.
 
-=head3 diff()
+=head3 diff
 
     my %staff    = ( bob => 42, martha => 35, timmy => 23 );
     my %promoted = ( timmy => 23 );
@@ -736,13 +831,14 @@ Returns the key/value pairs present in the first hash that are not
 present in the subsequent hash arguments.  Otherwise works as
 C<< @array->diff >>.
 
-=head3 intersect()
+=head3 intersect
 
     %staff->intersect(\%promoted); # { timmy => 23 }
 
 Returns the key/value pairs that are present simultaneously in all the
 hash arguments.  Otherwise works as C<< @array->intersect >>.
 
+
 =head2 Code autoboxing
 
 =head3 signature
@@ -757,22 +853,22 @@ signature.  See L<perl5i::Signature> for details.  Otherwise it
 returns nothing.
 
 
-=head2 caller()
+=head2 caller
 
 L<Perl6::Caller> causes C<caller> to return an object in scalar
 context.
 
-=head2 die()
+=head2 die
 
 C<die> now always returns an exit code of 255 instead of trying to use
 C<$!> or C<$?> which makes the exit code unpredictable.  If you want
 to exit with a message and a special exit code, use C<warn> then
 C<exit>.
 
-=head2 list()
+=head2 list
 
 C<list> will force list context similar to how
-L<perlfunc/scalar|scalar> will force scalar context.
+L<scalar|perlfunc/scalar> will force scalar context.
 
 
 =head2 utf8::all
@@ -801,7 +897,7 @@ STDOUT, STDIN, STDERR and all newly opened filehandles will have UTF8
 encoding turned on.  Consequently, if you want to output raw bytes to
 a file, such as outputting an image, you must set C<< binmode $fh >>.
 
-=head2 capture()
+=head2 capture
 
     my($stdout, $stderr) = capture { ... } %options;
     my $stdout = capture { ... } %options;
@@ -850,6 +946,9 @@ merge will merge C<STDOUT> and C<STDERR> into one variable.
 
 C<croak> and C<carp> from L<Carp> are always available.
 
+The Carp message will always format consistently, smoothing over the
+backwards incompatible change in Carp 1.25.
+
 =head2 Child
 
 L<Child> provides the C<child> function which is a better way to do forking.
@@ -881,8 +980,6 @@ You can also request a pipe for IPC:
 See L<Child> for more information.
 
 
-=back
-
 =head2 English
 
 L<English> gives English names to the punctuation variables; for
